Learn R Programming

muRL (version 0.1-2)

murljobs: A sample dataframe of recipient information and addresses

Description

This sample dataframe of recipient information and addresses includes columns with information required by the muRL package, as well as auxiliary columns with information related to a hypothetical mailmerge, but not required by muRL.

Usage

data(murljobs)

Arguments

source

Created by package authors.

Examples

Run this code
data(murljobs)

Run the code above in your browser using DataLab