murljobs: A sample dataframe of recipient information and addresses
Description
This sample dataframe of recipient information and addresses includes columns with information required by the muRL package, as well as auxiliary columns with information related to a hypothetical mailmerge, but not required by muRL.source
Created by package authors.